@@ -1,15 +1,14 @@
 from statsmodels.nonparametric.kernel_regression import KernelReg
 from typing import Tuple, List
 from random import randint, shuffle
-from dataclasses import dataclass
 import numpy as np
 from dovado_rtl.point_evaluation import DesignPointEvaluator, DesignValue
 
 
-@dataclass
 class Example:
-    design_point: List[int]
-    design_value: DesignValue
+    def __init__(self, design_point: List[int], design_value: DesignValue):
+        self.design_point: List[int] = design_point
+        self.design_value: DesignValue = design_value
 
 
 class Estimator:
