@@ -1,4 +1,4 @@
-from typing import List, OrderedDict, Optional, Tuple
+from typing import List, Optional, Tuple
 import numpy as np
 import dovado_rtl.user_input as user_input
 import dovado_rtl.report_parsing as report_utilities
@@ -118,9 +118,11 @@ def main():
         )
         return
 
-    free_parameters_range: OrderedDict[
-        str, Tuple[int, int]
-    ] = user_input.ask_parameters_range(free_parameters, config)
+    # OrderedDict from typing is available only from python 3.7 (we support python 3.6)
+    # OrderedDict[str, Tuple[int, int]]
+    free_parameters_range = user_input.ask_parameters_range(
+        free_parameters, config
+    )
 
     estimator: Estimator = Estimator(
         point_evaluator,
