@@ -2,8 +2,7 @@ import re
 from pathvalidate import is_valid_filepath
 from os import path
 from pathlib import Path
-from typing import Tuple, OrderedDict
-from collections import OrderedDict as CollOrderedDict
+from collections import OrderedDict
 import dovado_rtl.vivado_interaction as vivado
 import dovado_rtl.doc_parsing as doc
 from dovado_rtl.config import Configuration
@@ -312,7 +311,7 @@ def ask_identifiers(parsed_src: SourceFile):
 
 def ask_parameters_range(
     param_list, config: Configuration
-) -> OrderedDict[str, Tuple[int, int]]:
+):  # -> OrderedDict[str, Tuple[int, int]]
     shortcut = "_"
     print(
         "For each parameter specify a range e.g.'0 100' ,\n"
@@ -329,7 +328,7 @@ def ask_parameters_range(
     while i < len(param_list):
         user_input = input("Enter range for " + param_list[i] + ": ")
         if user_input == shortcut:
-            return CollOrderedDict(
+            return OrderedDict(
                 zip(
                     param_list,
                     param_range_accumulator
@@ -356,7 +355,7 @@ def ask_parameters_range(
         except Exception:
             print("Could not parse input as a pair of integers ")
 
-    return CollOrderedDict(zip(param_list, param_range_accumulator))
+    return OrderedDict(zip(param_list, param_range_accumulator))
 
 
 def ask_parameters(parsed_src: SourceFile):
