@@ -1,6 +1,4 @@
-from dataclasses import dataclass
 from enum import Enum, auto
-from typing import Dict, Tuple, List
 
 
 class RTL(Enum):
@@ -19,7 +17,7 @@ class ImplementationStep(Enum):
     ROUTE = auto()
 
 
-@dataclass
 class IsIncremental:
-    synthesis: bool = True
-    implementation: bool = True
+    def __init__(self, synthesis: bool, implementation: bool = False):
+        self.synthesis: bool = synthesis
+        self.implementation: bool = implementation
